@@ -96,22 +96,27 @@ class Video(ScrobblableMixin):
 
         video, created = cls.objects.get_or_create(**video_dict)
 
+        logger.debug(data_dict)
+        run_time_ticks = data_dict.get("RunTimeTicks", None)
+        if run_time_ticks:
+            run_time_ticks = run_time_ticks // 10000
+
         video_extra_dict = {
             "year": data_dict.get("Year", ""),
             "overview": data_dict.get("Overview", None),
             "tagline": data_dict.get("Tagline", None),
-            "run_time_ticks": data_dict.get("RunTimeTicks", 0) // 10000,
+            "run_time_ticks": run_time_ticks,
             "run_time": convert_to_seconds(data_dict.get("RunTime", "")),
             "tvdb_id": data_dict.get("Provider_tvdb", None),
             "tvrage_id": data_dict.get("Provider_tvrage", None),
-            "episode_number": data_dict.get("EpisodeNumber", ""),
-            "season_number": data_dict.get("SeasonNumber", ""),
+            "episode_number": data_dict.get("EpisodeNumber", None),
+            "season_number": data_dict.get("SeasonNumber", None),
         }
 
         if series:
             video_extra_dict["tv_series_id"] = series.id
 
-        if created:
+        if not video.run_time_ticks:
             logger.debug(f"Created new video: {video}")
             for key, value in video_extra_dict.items():
                 setattr(video, key, value)
